NodeDraggableBuilder class

A widget that wraps either Draggable or LongPressDraggable depending on the value of longPressDelay, with additional tree view capabilities.

It is also responsible for automatically collapsing the node it holds when the drag starts and expanding it back when the drag ends (if it was collapsed). This can be toggled off in collapseOnDragStart.

Usage:

Widget build(BuildContext context) {
  return NodeDraggableBuilder<Node>(
    node: entry.node,
    configuration: your configs,
    child: MyTreeNodeTile(),
  );
}
Inheritance

Constructors

NodeDraggableBuilder({required Widget child, required NodeComponentBuilder builder, required TreeConfiguration configuration, required Node node, required int depth, required int index, Key? key})
Creates a NodeDraggableBuilder.
const

Properties

builder NodeComponentBuilder
final
child Widget
The widget below this widget in the tree.
final
configuration TreeConfiguration
final
depth int
final
hashCode int
The hash code for this object.
no setterinherited
index int
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
node → Node
The tree node that is going to be provided to Draggable.data.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<NodeDraggableBuilder>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited